{% extends 'admin/model/list.html' %}
{% import 'admin/model/layout.html' as model_layout with context %}

{% block brand %}
    <h2 id="brand">{{ admin_view.name|capitalize }} list</h2>
    {% if admin_view.can_create %}
    <div class="btn-menu">
        <a href="{{ url_for('.create_view', url=return_url) }}" class="btn btn-primary pull-right">{{ _gettext('Create') }}</a>
    </div>
    {% endif %}

    {% if filter_groups %}
    <div class="btn-group btn-menu">
        {{ model_layout.filter_options(btn_class='btn dropdown-toggle btn-title') }}
    </div>
    {% endif %}

    {% if actions %}
    <div class="btn-group btn-menu">
        {{ actionlib.dropdown(actions, btn_class='btn dropdown-toggle btn-title') }}
    </div>
    {% endif %}

    {% if search_supported %}
    <div class="search-form btn-menu">
        {{ model_layout.search_form(input_class='span2 btn-title') }}
    </div>
    {% endif %}
    <div class="clearfix"></div>
    <hr>
{% endblock %}

{% block model_menu_bar %}
{% endblock %}
