{% import 'admin/layout.html' as layout with context -%}
{% extends 'admin/base.html' %}

{% block page_body %}
<div class="container">
  <div class="row">
    <div class="col-md-2">
      <ul class="nav nav-pills nav-stacked">
        {{ layout.menu() }}
        {{ layout.menu_links() }}
      </ul>
    </div>
    <div class="col-md-10">
      <div id="content">
        {% block brand %}
          <h2 id="brand">{{ admin_view.name|capitalize }}</h2>
          <div class="clearfix"></div>
        {% endblock %}
        {{ layout.messages() }}
        {% block body %}
        {% endblock %}
      </div>
    </div>
  </div>
</div>
{% endblock %}
